@@ -3,7 +3,7 @@ package Perl::Critic::Freenode;
 use strict;
 use warnings;
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 1;
 
@@ -16,6 +16,10 @@ freenode IRC
 
   $ perlcritic --theme freenode script.pl
   $ perlcritic --theme freenode lib/
+  
+  # .perlcriticrc
+  theme = freenode
+  severity = 1
 
 =head1 DESCRIPTION
 
@@ -40,6 +44,10 @@ announcing their participation in this grouping.
 
 Don't use C<&> to call subroutines
 
+=item L<Perl::Critic::Policy::Freenode::ArrayAssignAref>
+
+Don't assign an anonymous arrayref to an array
+
 =item L<Perl::Critic::Policy::Freenode::BarewordFilehandles>
 
 Don't use bareword filehandles other than built-ins
